@@ -1,6 +1,7 @@
 __all__ = [
     "WildcardResourceRule",
 ]
+import json
 import logging
 from typing import Dict, Optional
 
@@ -60,7 +61,19 @@ class WildcardResourceRule(ResourceSpecificRule):
             if hasattr(resource, "Properties"):
                 policy_document = resource.Properties.get("PolicyDocument")
                 if policy_document:
-                    self._check_policy_document(result, logical_id, PolicyDocument(**policy_document), None, extras)
+                    try:
+                        # PolicyDocument requires a dict. If we receive a string, attempt a conversion to dict.
+                        # If this conversion fails, show the appropriate warning and continue.
+                        formatted_policy_document = (
+                            json.loads(policy_document) if isinstance(policy_document, str) else policy_document
+                        )
+                        self._check_policy_document(
+                            result, logical_id, PolicyDocument(**formatted_policy_document), None, extras
+                        )
+                    except Exception:
+                        logger.warning(
+                            f"Could not process the PolicyDocument {policy_document} on {logical_id}", stack_info=True
+                        )
 
         return result
 
